@@ -5,11 +5,11 @@ import datetime
 from sqlalchemy import distinct
 from sqlalchemy.sql import func
 import pandas as pd
-
+import numpy as np
 from ...util.singleton import Singleton
 from ..wrapper.mysql import BasicDatabaseConnector
 from ..view.basic_models import *
-
+from .raw import RawDataApi
 
 class BasicDataApi(metaclass=Singleton):
     def get_trading_day_list(self, start_date='', end_date=''):
@@ -172,12 +172,32 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundBenchmark.__tablename__}')
 
-    def get_index_info(self):
+    def get_index_info(self, index_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                         IndexInfo
                     )
+                if index_list:
+                    query = query.filter(
+                        IndexInfo.index_id.in_(index_list)
+                    )
+                tag_df = pd.read_sql(query.statement, query.session.bind)
+                return tag_df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {IndexInfo.__tablename__}')
+
+    def get_index_info_by_em_id(self, em_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        IndexInfo
+                    )
+                if em_id_list:
+                    query = query.filter(
+                        IndexInfo.em_id.in_(em_id_list)
+                    )
                 tag_df = pd.read_sql(query.statement, query.session.bind)
                 return tag_df
 
@@ -1136,21 +1156,6 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'failed to get_fof_scale_alteration <err_msg> {e} from {FOFScaleAlteration.__tablename__}')
 
 
-    def get_fof_asset_allocation(self, fof_id_list: Tuple[str] = ()):
-        with BasicDatabaseConnector().managed_session() as db_session:
-            try:
-                query = db_session.query(
-                    FOFAssetAllocation,
-                )
-                if fof_id_list:
-                    query = query.filter(
-                        FOFAssetAllocation.fof_id.in_(fof_id_list),
-                    )
-                return pd.read_sql(query.statement, query.session.bind)
-            except Exception as e:
-                print(f'failed to get_fof_asset_allocation <err_msg> {e} from {FOFAssetAllocation.__tablename__}')
-
-
     def get_fof_manually(self, fof_id_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -1251,6 +1256,34 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFInvestorPosition.__tablename__}')
                 return False
 
+    def get_fof_investor_position_summary(self, investor_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFInvestorPositionSummary,
+                )
+                if investor_id_list:
+                    query = query.filter(
+                        FOFInvestorPositionSummary.investor_id.in_(investor_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_investor_position_summary <err_msg> {e} from {FOFInvestorPositionSummary.__tablename__}')
+
+    def delete_fof_investor_position_summary(self, investor_id_to_delete: str, datetime_list: List[datetime.date]) -> bool:
+        with BasicDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFInvestorPositionSummary
+                ).filter(
+                    FOFInvestorPositionSummary.datetime.in_(datetime_list),
+                    FOFInvestorPositionSummary.investor_id == investor_id_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFInvestorPositionSummary.__tablename__}')
+
     def get_fof_estimate_fee(self, fof_id_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -1337,3 +1370,354 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to delete data <err_msg> {e} from {FOFTransitMoney.__tablename__}')
                 return False
+
+    def get_asset_info(self, asset_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    AssetInfo,
+                )
+                if asset_id_list:
+                    query = query.filter(
+                        AssetInfo.asset_id.in_(asset_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
+
+    def get_asset_info_real(self, real_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    AssetInfo,
+                )
+                if real_id_list:
+                    query = query.filter(
+                        AssetInfo.real_id.in_(real_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
+
+    def get_asset_details(self):
+        try:
+            df = self.get_asset_info()
+            asset_list = df.asset_type.unique().tolist()
+            result = {}
+            for asset_id in asset_list:
+                result[asset_id] = []
+                _df = df[df.asset_type == asset_id].drop_duplicates(subset=['asset_name'])
+                for r in _df.itertuples():
+                    result[asset_id].append([r.asset_id, r.asset_name])
+            return result
+        except Exception as e:
+            print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
+
+    def get_product_details(self):
+        try:
+            df = self.get_asset_info()
+            df1 = df[(df['asset_type'] == '典型产品')]
+            asset_list = df1.asset_name.unique().tolist()
+            result = {}
+            for asset_id in asset_list:
+                result[asset_id] = []
+                _df = df1[df1.asset_name == asset_id]
+                for r in _df.itertuples():
+                    result[asset_id].append([r.real_id, r.real_name])
+            df2 = df[df['asset_name'].isin(['商品','大盘股'])]
+            asset_list = df2.asset_name.unique().tolist()
+            dic = {'商品CFCI':'商品期货指数'}
+            asset = '指数'
+            result[asset] = []
+            for r in df2.itertuples():
+                result[asset].append([r.real_id, dic.get(r.real_name,r.real_name)])
+            return result
+        except Exception as e:
+            print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
+
+    def get_asset_price(self, asset_list: Tuple[str] = ()):
+        try:
+            raw = RawDataApi()
+            asset_info = self.get_asset_info(asset_id_list=asset_list)
+            asset_list = asset_info.asset_id.tolist()
+            _asset_list = [i for i in asset_list if i.split('-')[0] == 'fund']
+            _res = []
+            for r in asset_info.itertuples():
+                if r.asset_id in _asset_list:
+                    _res.append(r.real_name)
+                else:
+                    _res.append(r.asset_name)
+            asset_info.loc[:,'show_name'] = _res
+            inputs_asset_list = asset_info.asset_id.tolist()
+            asset_dic = asset_info.set_index('asset_id').to_dict()['real_id']
+            asset_list_0 = ['asset-dollar']
+            asset_list_1 = ['asset-btc']
+            asset_list_2 = ['asset-usdebt']
+            _asset_list_0 = [i for i in inputs_asset_list if i in asset_list_0]
+            _asset_list_1 = [i for i in inputs_asset_list if i in asset_list_1]
+            _asset_list_2 = [i for i in inputs_asset_list if i in asset_list_2]
+            _asset_list_3 = [i for i in inputs_asset_list if i.split('-')[0] == 'fund']
+            _asset_list_4 = [i for i in inputs_asset_list if i.split('-')[0] == 'stgindex']
+            _asset_sum = _asset_list_0 + _asset_list_1 + _asset_list_2 + _asset_list_3 + _asset_list_4
+            _asset_list_5 = [i for i in inputs_asset_list if i not in _asset_sum]
+
+            result = []
+            if len(_asset_list_0) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_0]
+                _df = raw.get_em_macroeconomic_daily(codes=real_ids,).pivot_table(index='datetime',columns='codes',values='value')
+                result.append(_df)
+            if len(_asset_list_1) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_1]
+                _df = raw.get_btc(asset_ids=real_ids).pivot_table(index='date',columns='codes',values='close')
+                result.append(_df)
+            if len(_asset_list_2) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_2]
+                _df = raw.get_em_future_price(future_ids=real_ids).pivot_table(index='datetime',columns='future_id',values='close')
+                result.append(_df)
+            if len(_asset_list_3) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_3]
+                _df = raw.get_hf_fund_nav(fund_ids=real_ids).pivot_table(index='datetime',columns='fund_id',values='nav')
+                result.append(_df)
+            if len(_asset_list_4) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_4]
+                _df = raw.get_hf_index_price(index_ids=real_ids).pivot_table(index='index_date',columns='index_id',values='close')
+                result.append(_df)
+            if len(_asset_list_5) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_5]
+                _df = self.get_index_price(index_list=real_ids).pivot_table(index='datetime',columns='index_id',values='close')
+                result.append(_df)
+
+            df_result = pd.concat(result,axis=1).sort_index().ffill().dropna()
+            df_result = df_result / df_result.iloc[0]
+            df_result_show = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['show_name'])
+            df_result_real = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['real_name'])
+            asset_info = asset_info.drop_duplicates(subset=['real_id'])
+            dic = {'data':df_result_show,'_input_asset_nav':df_result_real,'_input_asset_info':asset_info}
+            return dic
+        
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.get_asset_price')
+
+    def get_product_price(self, product_id_list: Tuple[str] = ()):
+        try:
+            raw = RawDataApi()
+            asset_info = self.get_asset_info_real(real_id_list=product_id_list)
+            asset_list = asset_info.asset_id.tolist()
+            _asset_list = [i for i in asset_list if i.split('-')[0] == 'fund']
+            _res = []
+            for r in asset_info.itertuples():
+                if r.asset_id in _asset_list:
+                    _res.append(r.real_name)
+                else:
+                    _res.append(r.asset_name)
+            asset_info.loc[:,'show_name'] = _res
+            inputs_asset_list = asset_info.asset_id.tolist()
+            asset_dic = asset_info.set_index('asset_id').to_dict()['real_id']
+            asset_list_0 = ['asset-dollar']
+            asset_list_1 = ['asset-btc']
+            asset_list_2 = ['asset-usdebt']
+            _asset_list_0 = [i for i in inputs_asset_list if i in asset_list_0]
+            _asset_list_1 = [i for i in inputs_asset_list if i in asset_list_1]
+            _asset_list_2 = [i for i in inputs_asset_list if i in asset_list_2]
+            _asset_list_3 = [i for i in inputs_asset_list if i.split('-')[0] == 'fund']
+            _asset_list_4 = [i for i in inputs_asset_list if i.split('-')[0] == 'stgindex']
+            _asset_sum = _asset_list_0 + _asset_list_1 + _asset_list_2 + _asset_list_3 + _asset_list_4
+            _asset_list_5 = [i for i in inputs_asset_list if i not in _asset_sum]
+
+            result = []
+            if len(_asset_list_0) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_0]
+                _df = raw.get_em_macroeconomic_daily(codes=real_ids,).pivot_table(index='datetime',columns='codes',values='value')
+                result.append(_df)
+            if len(_asset_list_1) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_1]
+                _df = raw.get_btc(asset_ids=real_ids).pivot_table(index='date',columns='codes',values='close')
+                result.append(_df)
+            if len(_asset_list_2) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_2]
+                _df = raw.get_em_future_price(future_ids=real_ids).pivot_table(index='datetime',columns='future_id',values='close')
+                result.append(_df)
+            if len(_asset_list_3) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_3]
+                _df = raw.get_hf_fund_nav(fund_ids=real_ids).pivot_table(index='datetime',columns='fund_id',values='nav')
+                result.append(_df)
+            if len(_asset_list_4) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_4]
+                _df = raw.get_hf_index_price(index_ids=real_ids).pivot_table(index='index_date',columns='index_id',values='close')
+                result.append(_df)
+            if len(_asset_list_5) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_5]
+                _df = self.get_index_price(index_list=real_ids).pivot_table(index='datetime',columns='index_id',values='close')
+                result.append(_df)
+
+            df_result = pd.concat(result,axis=1).sort_index().ffill().dropna()
+            df_result = df_result / df_result.iloc[0]
+            df_result_show = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['show_name'])
+            df_result_real = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['real_name'])
+            asset_info = asset_info.drop_duplicates(subset=['real_id'])
+            dic = {'data':df_result_show,'_input_asset_nav':df_result_real,'_input_asset_info':asset_info}
+            return dic
+        
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.get_asset_price')
+
+
+    def data_resample_monthly_nav(self, df, rule='1M'):
+        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).last()
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        return df
+
+    def asset_recent_rate(self, year:int=None):
+        #如果year为空 返回年度收益
+        #如果year为整数 返回当年月度收益 year从2010开始
+        try:
+            index_list = ['hs300','sse','gem','sme','sse50','csi500','csi800','szse_a']
+            index_info = self.get_index_info(index_list=index_list)
+            desc_name_dic = index_info.set_index('index_id').to_dict()['desc_name']
+            index_price = self.get_index_price_dt(start_date='20091231',index_list=index_list).pivot_table(index='datetime',columns='index_id',values='close')
+            if year is None:
+                # 年度
+                index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
+                index_ret_year = index_price_y.pct_change(1).dropna()
+                td = index_ret_year.index
+                td = [str(i.year) for i in td]
+                index_ret = index_ret_year.copy()
+            else:
+                index_price_m = index_price.loc[datetime.date(year-1,12,31):datetime.date(year,12,31)]
+                index_price_m = self.data_resample_monthly_nav(index_price_m,rule='1M').bfill()
+                index_ret_m = index_price_m.pct_change(1).dropna()
+                td = index_ret_m.index
+                td = [str(i.year) + str(i.month).zfill(2) for i in td ]
+                index_ret = index_ret_m.copy()
+            index_ret.index = td
+            index_ret.loc['均值',:] = index_ret.mean()
+            index_ret = index_ret.round(4)*100
+            index_ret = index_ret.rename(columns=desc_name_dic)
+            return index_ret.T
+
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.asset_recent_rate')
+            
+    def market_size_df(self,begin_date, end_date, time_para, codes=['cninfo_smallcap','cni_largec','cni_midcap']):
+        try:
+            begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
+            index_price = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=codes)
+            index_info = self.get_index_info(codes)
+            index_price = index_price.pivot_table(index='datetime',columns='index_id',values='close').dropna()
+            dic = index_info.set_index('index_id').to_dict()['desc_name']
+            index_price = index_price / index_price.iloc[0] - 1
+            index_price = index_price.rename(columns=dic)
+            index_price.index.name = 'datetime'
+            return index_price
+
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.market_size_df')
+
+    def get_main_index_future_diff_yearly(self, begin_date, end_date, time_para, codes=['EMM00597141','EMM00597142','EMM00597143']):
+        try:
+            
+            def is_third_friday(d):
+                return d.weekday() == 4 and 15 <= d.day <= 21
+            # 当月连续合约换仓天数
+            def this_months_ex(x):
+                return exchange_dts[exchange_dts >= x][0]
+            # 下月连续合约换仓天数
+            def next_months_ex(x):
+                return exchange_dts[exchange_dts >= datetime.date(year=x.year,month=x.month,day=28)][0]
+            # 下季度连续合约换仓天数
+            def this_season_ex(x):
+                return exchange_dts[(exchange_dts >= x) & ([i.month in [3,6,9,12] for i in exchange_dts])][1]
+
+            begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
+
+            # begin_date = max(begin_date, datetime.date(2020,1,1))
+            codes = ['EMM00597141','EMM00597142','EMM00597143']
+            df = RawDataApi().get_stock_index_future_diff_base(begin_date,end_date,codes)
+            index_price = self.get_index_price_dt(start_date=begin_date,index_list=['csi500'])
+            index_price = index_price.pivot_table(columns='index_id',values='close',index='datetime')
+            df = df.join(index_price)
+            for code_i in codes:
+                df[code_i] = df[code_i] / df.csi500
+
+            dt1 = [i for i in df.index if is_third_friday(i)]
+            dt2 = []
+            for i in range(200):
+                _d = df.index.values[-1] + datetime.timedelta(i)
+                if is_third_friday(_d):
+                    dt2.append(_d)
+            exchange_dts = np.array(dt1 + dt2)
+            exchange_dts = np.array([i - datetime.timedelta(days=4) for i in exchange_dts])    
+                
+            df.loc[:,'当月连续剩余交易日'] = df.index.map(lambda x: (this_months_ex(x) - x).days + 4)
+            df.loc[:,'下月连续剩余交易日'] = df.index.map(lambda x: (next_months_ex(x) - x).days + 4)
+            df.loc[:,'下季连续剩余交易日'] = df.index.map(lambda x: (this_season_ex(x) - x).days + 4)
+
+            df['EMM00597141'] = df['EMM00597141'] * 250 / df['当月连续剩余交易日']
+            df['EMM00597142'] = df['EMM00597142'] * 250 / df['下月连续剩余交易日']
+            df['EMM00597143'] = df['EMM00597143'] * 250 / df['下季连续剩余交易日']
+
+            dic = {
+                        'EMM00597141':'IC当月连续年化贴水率',
+                        'EMM00597142':'IC下月连续年化贴水率',
+                        'EMM00597143':'IC下季连续年化贴水率',
+                    }
+            df = df[codes].rename(columns=dic)
+            df.index.name = 'datetime'
+            return df
+
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.get_main_index_future_diff_yearly')
+    
+    def get_indus_info_list(self):
+        try:
+            df = RawDataApi().get_em_industry_info(ind_class_type=1)[['em_id','ind_name']]
+            em_id_list = df.em_id.to_list()
+            df = self.get_index_info_by_em_id(em_id_list)
+            info_list = [(r.index_id,r.desc_name.replace('(申万)','')) for r in df.itertuples()]
+            return info_list
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from get_em_industry_info')
+            return []
+
+    def get_industry_price(self, begin_date, end_date, time_para, index_list):
+        try:
+            begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
+            df_info = self.get_index_info(index_list)
+            info_dic = {r.index_id : r.desc_name.replace('(申万)','') for r in df_info.itertuples()}
+            df = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=index_list)
+            df = df.pivot_table(columns='index_id',values='close',index='datetime')
+            df = df / df.iloc[0]
+            df = df.rename(columns=info_dic)
+            return df
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from get_industry_price')
+            return pd.DataFrame([])
+
+    def get_industry_recent_ret(self, index_list, year:int=None):
+        try:
+            df_info = self.get_index_info(index_list)
+            desc_name_dic = {r.index_id : r.desc_name.replace('(申万)','') for r in df_info.itertuples()}
+            index_price = self.get_index_price_dt(start_date='20091231',index_list=index_list).pivot_table(index='datetime',columns='index_id',values='close')
+            if year is None:
+                # 年度
+                index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
+                index_ret_year = index_price_y.pct_change(1).dropna()
+                td = index_ret_year.index
+                td = [str(i.year) for i in td]
+                index_ret = index_ret_year.copy()
+            else:
+                index_price_m = index_price.loc[datetime.date(year-1,12,31):datetime.date(year,12,31)]
+                index_price_m = self.data_resample_monthly_nav(index_price_m,rule='1M').bfill()
+                index_ret_m = index_price_m.pct_change(1).dropna()
+                td = index_ret_m.index
+                td = [str(i.year) + str(i.month).zfill(2) for i in td ]
+                index_ret = index_ret_m.copy()
+            index_ret.index = td
+            index_ret.loc['均值',:] = index_ret.mean()
+            index_ret = index_ret.round(4)*100
+            index_ret = index_ret.rename(columns=desc_name_dic)
+            return index_ret.T
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.get_industry_recent_ret')
\ No newline at end of file
