@@ -33,6 +33,7 @@ class HedgeFundNAVReader:
         '虚拟净值': 'v_net_value',
         '计提后单位净值': 'v_net_value',
         '虚拟计提净值': 'v_net_value',
+        '虚拟后单位净值': 'v_net_value',
         '复权累计净值': 'adjusted_net_value',
         '复权净值': 'adjusted_net_value',
         '净值(分红再投)': 'adjusted_net_value',
@@ -43,6 +44,9 @@ class HedgeFundNAVReader:
     }
 
     def __init__(self, read_dir: str, user_name: str, password: str):
+        pd.set_option('display.max_rows', None)
+        pd.set_option('display.max_columns', None)
+
         self._read_dir = read_dir
         assert os.path.isdir(self._read_dir), f'arg dump_dir should be a directory (now){self._read_dir}'
 
@@ -51,7 +55,7 @@ class HedgeFundNAVReader:
         self._wechat_bot = WechatBot()
 
     @staticmethod
-    def _read_for_HuangChengZhiYuanNo3WithoutV(file_path: str) -> pd.DataFrame:
+    def _read_for_HuaChengZhiYuanNo3WithoutV(file_path: str) -> pd.DataFrame:
         df = pd.read_excel(file_path, header=None)
         df.iloc[:, 0] = df.iloc[:, 0].map(lambda x: x.split('：')[0])
         df = df.set_index(df.columns[0])
@@ -62,7 +66,7 @@ class HedgeFundNAVReader:
         return df
 
     @staticmethod
-    def _read_for_HuangChengZhiYuanNo3(file_path: str) -> pd.DataFrame:
+    def _read_for_HuaChengZhiYuanNo3(file_path: str) -> pd.DataFrame:
         df = pd.read_excel(file_path)
         df = df.loc[:, ['产品代码', '产品名称', '业务日期', '单位净值', '累计单位净值', '虚拟后净值']]
         df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
@@ -149,6 +153,32 @@ class HedgeFundNAVReader:
         df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
         return df
 
+    @staticmethod
+    def _read_for_BoPu6WithoutV(file_path: str) -> pd.DataFrame:
+        df = pd.read_excel(file_path, header=None)
+        df.iloc[:, 0] = df.iloc[:, 0].map(lambda x: x.split('：')[0])
+        df = df.set_index(df.columns[0])
+        pat = r'\d+'
+        date = re.findall(pat, df.index.array[2])
+        df = df.T.loc[:, ['基金代码', '基金名称', '基金份额净值', '基金份额累计净值']]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT).assign(datetime=pd.to_datetime('-'.join(date), infer_datetime_format=True).date())
+        return df
+
+    @staticmethod
+    def _read_for_YuanHui1(file_path: str) -> pd.DataFrame:
+        df = pd.read_excel(file_path)
+        df = df.loc[:, ['产品名称', '产品代码', '业务日期', '单位净值', '累计单位净值', '虚拟后单位净值']]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        return df
+
+    @staticmethod
+    def _read_for_ZhuoShiJiaXin(file_path: str) -> pd.DataFrame:
+        df = pd.read_excel(file_path)
+        df = df.loc[:, ['产品名称', '产品代码', '业务日期', '单位净值', '累计单位净值', '虚拟后净值']]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
+        return df
+
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
         self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
@@ -180,9 +210,9 @@ class HedgeFundNAVReader:
 
             try:
                 if 'SGM473' in name:
-                    df = HedgeFundNAVReader._read_for_HuangChengZhiYuanNo3WithoutV(file_path)
+                    df = HedgeFundNAVReader._read_for_HuaChengZhiYuanNo3WithoutV(file_path)
                 elif '华澄致远三号' in name:
-                    df = HedgeFundNAVReader._read_for_HuangChengZhiYuanNo3(file_path)
+                    df = HedgeFundNAVReader._read_for_HuaChengZhiYuanNo3(file_path)
                 elif 'SLC213_天演广全' in name:
                     df = HedgeFundNAVReader._read_for_TianYanGuangQuanWithoutV(file_path)
                 elif '天演广全' in name:
@@ -204,6 +234,12 @@ class HedgeFundNAVReader:
                         df = HedgeFundNAVReader._read_for_TaiChuangXiShuoCTANormal(file_path)
                 elif '博普量化对冲6号' in name:
                     df = HedgeFundNAVReader._read_for_BoPu6(file_path)
+                elif 'SEE891-发送每日净值' in name:
+                    df = HedgeFundNAVReader._read_for_BoPu6WithoutV(file_path)
+                elif '源晖量化一号' in name:
+                    df = HedgeFundNAVReader._read_for_YuanHui1(file_path)
+                elif '卓识佳鑫' in name:
+                    df = HedgeFundNAVReader._read_for_ZhuoShiJiaXin(file_path)
                 else:
                     raise NotImplementedError('unknown hedge fund nav file from attachment')
             except Exception as e:
@@ -261,11 +297,11 @@ class HedgeFundNAVReader:
         now_df = BasicDataApi().get_hedge_fund_nav(fund_id_list=list(df.fund_id.unique()))
         if now_df is not None and not now_df.empty:
             # 同产品同日期的净值如果已经存在了且没有变化，就不写DB了
-            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'change_rate', 'adjusted_net_value']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset=['fund_id', 'datetime'], keep='last')
+            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'change_rate']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset=['fund_id', 'datetime'], keep='last')
             now_df = now_df.astype({'net_asset_value': 'float64', 'acc_unit_value': 'float64', 'v_net_value': 'float64'})
             df = df.reindex(columns=now_df.columns).astype(now_df.dtypes.to_dict())
             df = df.merge(now_df, how='left', on=['fund_id', 'datetime', 'net_asset_value', 'acc_unit_value', 'v_net_value'], indicator=True, validate='one_to_one')
-            df = df[df._merge == 'left_only'].drop(columns=['_merge', 'insert_time_y', 'calc_date_y']).rename(columns={'insert_time_x': 'insert_time', 'calc_date_x': 'calc_date'})
+            df = df[df._merge == 'left_only'].drop(columns=['_merge', 'insert_time_y', 'calc_date_y', 'adjusted_net_value_y', 'ta_factor_y']).rename(columns={'insert_time_x': 'insert_time', 'calc_date_x': 'calc_date', 'adjusted_net_value_x': 'adjusted_net_value', 'ta_factor_x': 'ta_factor'})
             if df.empty:
                 return
             # FIXME 没想到特别好的方法 遍历每一行再check一下
@@ -274,6 +310,12 @@ class HedgeFundNAVReader:
             if df.empty:
                 return
             df['insert_time'] = df.insert_time.map(lambda x: x.to_pydatetime())
+            print(df)
+            df.update(now_df, overwrite=False)
+            print(df)
+            # 先删后添
+            for fund_id in df.fund_id.unique():
+                BasicDataApi().delete_hedge_fund_nav(fund_id_to_delete=fund_id, date_list=df[df.fund_id == fund_id].datetime.to_list())
         df.to_sql(HedgeFundNAV.__table__.name, BasicDatabaseConnector().get_engine(), index=False, if_exists='append')
         return df
 
