@@ -13,8 +13,8 @@ class Base:
 
 
 class FOFBase:
-    create_time = Column(DATETIME, nullable=False, default=datetime.datetime.now)  # 创建时间
-    update_time = Column(DATETIME, nullable=False, default=datetime.datetime.now, onupdate=datetime.datetime.now)  # 更新时间
+    create_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP'))  # 创建时间
+    update_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP'))  # 更新时间
     is_deleted = Column(BOOLEAN, nullable=False, server_default=text('FALSE'))  # 是否删除 默认不删除
 
 
@@ -637,6 +637,17 @@ class FundCompCoreMng(Base):
     fund_type = Column(CHAR(25)) # 基金类型
     region = Column(CHAR(5)) # 监管辖区
 
+class AssetInfo(Base):
+    '''大类资产对应信息'''
+
+    __tablename__ = 'asset_info'
+
+    asset_id = Column(CHAR(40), primary_key=True) # 代码
+    real_id = Column(CHAR(20), primary_key=True) # 真实代码
+    asset_name = Column(CHAR(15)) # 资产名
+    real_name = Column(CHAR(40)) # 真实名字
+    asset_type = Column(CHAR(10)) # 资产名
+
 class FundIPOStats(Base):
     '''基金打新收益率统计'''
 
@@ -797,6 +808,7 @@ class HedgeFundNAV(FOFBase):
     adjusted_net_value = Column(DOUBLE(asdecimal=False)) # 复权净值
     v_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值的虚拟后净值
     change_rate = Column(DOUBLE(asdecimal=False))   # 涨跌幅
+    ta_factor = Column(DOUBLE(asdecimal=False))   # 复权因子
 
     # 不能加这个 会影响fof backend项目
     # __table_args__ = (
@@ -867,7 +879,8 @@ class FOFInfo(FOFBase):
     __tablename__ = 'fof_info'
 
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    datetime = Column(CHAR(16), primary_key=True)  # 数据日期（以支持更新操作）
+    manager_id = Column(VARCHAR(32), primary_key=True)  # 管理端ID
+    datetime = Column(CHAR(16))  # 数据日期（以支持更新操作）
     fof_name = Column(TEXT, nullable=False)  # 产品名称
     admin = Column(TEXT, nullable=False)  # 管理人
     established_date = Column(DATE, nullable=False)  # 成立日期
@@ -890,12 +903,31 @@ class FOFInfo(FOFBase):
     net_asset_value = Column(DOUBLE(asdecimal=False))  # 单位净值
     acc_unit_value = Column(DOUBLE(asdecimal=False))  # 累计净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
-    is_calculating = Column(BOOLEAN, default=False)       # 是否正在计算
+    ret_year_to_now = Column(DOUBLE(asdecimal=False))       # 今年以来收益率
+    ret_total = Column(DOUBLE(asdecimal=False))             # 总收益率
+    ret_ann = Column(DOUBLE(asdecimal=False))               # 总收益率年化
+    mdd = Column(DOUBLE(asdecimal=False))                   # 最大回撤
+    sharpe = Column(DOUBLE(asdecimal=False))                # 夏普比率
+    vol = Column(DOUBLE(asdecimal=False))                   # 波动率
+    is_calculating = Column(BOOLEAN, default=False)         # 是否正在计算
     latest_cal_date = Column(DATETIME)                      # 最新净值日
     strategy_type = Column(Integer)                         # 策略类型
     risk_type = Column(Integer)                             # 风险等级
     is_on_sale = Column(BOOLEAN, default=False)             # 是否上架
-    sale_status = Column(Integer)                           # 状态
+    is_fof = Column(BOOLEAN, default=False)                 # 是否为fof计算产品
+    is_top = Column(BOOLEAN, default=False)                 # 是否置顶
+    benchmark = Column(VARCHAR(63))                         # 默认业绩基准
+    asset_type = Column(VARCHAR(63))                        # 产品类型
+    nav_freq = Column(VARCHAR(31))                          # 净值频率
+    fund_no = Column(CHAR(6))                               # 基金编号
+    management_ids = Column(VARCHAR(255))                   # 所属机构ID
+    filing_date = Column(DATE)                              # 备案时间
+    filing_stage = Column(VARCHAR(16))                      # 基金备案阶段
+    fund_type = Column(VARCHAR(16))                         # 基金类型
+    currency_type = Column(VARCHAR(16))                     # 币种
+    management_type = Column(VARCHAR(16))                   # 管理类型
+    custodian_name = Column(VARCHAR(128))                   # 托管人名称
+    fund_status = Column(VARCHAR(16))                       # 运作状态
 
 
 class FOFScaleAlteration(FOFBase):
@@ -905,6 +937,7 @@ class FOFScaleAlteration(FOFBase):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    manager_id = Column(VARCHAR(32))  # 管理端ID
     datetime = Column(DATE, primary_key=True)  # 确认日期
     investor_id = Column(CHAR(16), nullable=False)  # 投资人ID
     applied_date = Column(DATE)  # 申请日期
@@ -960,6 +993,7 @@ class FOFInvestorInfo(Base):
     __tablename__ = 'fof_investor_info'
 
     investor_id = Column(CHAR(16), primary_key=True)  # 客户合同号(投资人ID)
+    manager_id = Column(VARCHAR(32))  # 管理端ID
     investor_name = Column(CHAR(8), nullable=False)  # 姓名
 
 
@@ -969,6 +1003,7 @@ class FOFInvestorPosition(FOFBase):
     __tablename__ = 'fof_investor_position'
 
     investor_id = Column(CHAR(16), primary_key=True)  # 投资人ID
+    manager_id = Column(VARCHAR(32))  # 管理端ID
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
     datetime = Column(DATE, primary_key=True)  # 日期
     v_nav = Column(DOUBLE(asdecimal=False))  # 对应到投资人的虚拟净值
@@ -986,6 +1021,7 @@ class FOFInvestorPositionSummary(FOFBase):
     __tablename__ = 'fof_investor_position_summary'
 
     investor_id = Column(CHAR(16), primary_key=True)  # 投资人ID
+    manager_id = Column(VARCHAR(32))  # 管理端ID
     datetime = Column(DATE, primary_key=True)  # 日期
     mv = Column(DOUBLE(asdecimal=False))  # 总市值(总资产)
     amount = Column(DOUBLE(asdecimal=False))  # 总投资额(总本金)
