@@ -13,8 +13,8 @@ class Base:
 
 
 class FOFBase:
-    create_time = Column(DATETIME, nullable=False, default=datetime.datetime.now)  # 创建时间
-    update_time = Column(DATETIME, nullable=False, default=datetime.datetime.now, onupdate=datetime.datetime.now)  # 更新时间
+    create_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP'))  # 创建时间
+    update_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP'))  # 更新时间
     is_deleted = Column(BOOLEAN, nullable=False, server_default=text('FALSE'))  # 是否删除 默认不删除
 
 
@@ -723,6 +723,7 @@ class FOFNavPublic(FOFBase):
     datetime = Column(DATE, primary_key=True)               # 日期
     nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
+    adjusted_nav = Column(DOUBLE(asdecimal=False))  # 复权净值
     volume = Column(DOUBLE(asdecimal=False))                # 份额
     mv = Column(DOUBLE(asdecimal=False))                    # 市值
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
@@ -746,6 +747,7 @@ class FOFInvestorData(FOFBase):
 
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
     investor_id = Column(CHAR(16), primary_key=True)  # 客户合同号(投资人ID)
+    manager_id = Column(CHAR(32))  # 管理端ID
     total_investment = Column(DOUBLE(asdecimal=False))  # 总投资额
 
 
@@ -768,3 +770,60 @@ class FOFPositionDetail(FOFBase):
     latest_mv = Column(DOUBLE(asdecimal=False), nullable=False)  # 当日市值
     total_ret = Column(DOUBLE(asdecimal=False), nullable=False)  # 累计收益
     total_rr = Column(DOUBLE(asdecimal=False), nullable=False)  # 累计收益率
+
+
+class HedgeFundInvestorPurAndRedemp(FOFBase):
+    '''私募客户申赎数据'''
+
+    __tablename__ = 'hedge_fund_investor_pur_redemp'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    datetime = Column(DATE, primary_key=True)  # 交易日期
+    applied_date = Column(DATE)  # 申请日期
+    deposited_date = Column(DATE)  # 交割日期
+    event_type = Column(Integer, nullable=False)  # 交易类型
+    investor_id = Column(CHAR(16), nullable=False)  # 客户合同号(投资人ID)
+    net_asset_value = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
+    acc_unit_value = Column(DOUBLE(asdecimal=False), nullable=False)  # 累计净值
+    purchase_amount = Column(DOUBLE(asdecimal=False))  # 申认购金额(元)
+    redemp_confirmed_amount = Column(DOUBLE(asdecimal=False))  # 赎回确认金额(元)
+    raising_interest = Column(DOUBLE(asdecimal=False))  # 募集期利息(元)
+    redemp_fee = Column(DOUBLE(asdecimal=False))  # 赎回费(元)
+    carry_amount = Column(DOUBLE(asdecimal=False))  # 业绩报酬金额(元)
+    share_changed = Column(DOUBLE(asdecimal=False), nullable=False)  # 份额变更
+    share_after_trans = Column(DOUBLE(asdecimal=False), nullable=False)  # 交易后份额
+
+
+class HedgeFundInvestorPurAndRedempSub(FOFBase):
+    """私募客户申赎数据附表"""
+
+    __tablename__ = 'hedge_fund_investor_pur_redemp_sub'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    main_id = Column(Integer)
+    trade_confirm_url = Column(CHAR(127))                       # 交易确认单
+    trade_apply_url = Column(CHAR(127))                         # 交易申请表
+    remark = Column(CHAR(255))                                  # 备注
+
+
+class HedgeFundInvestorDivAndCarry(FOFBase):
+    '''私募客户分红/业绩计提数据'''
+
+    __tablename__ = 'hedge_fund_investor_div_carry'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    datetime = Column(DATE, primary_key=True)  # 交易日期
+    applied_date = Column(DATE)  # 申请日期
+    deposited_date = Column(DATE)  # 交割日期
+    event_type = Column(Integer, nullable=False)  # 交易类型
+    investor_id = Column(CHAR(16), nullable=False)  # 客户合同号(投资人ID)
+    net_asset_value = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
+    acc_unit_value = Column(DOUBLE(asdecimal=False), nullable=False)  # 累计净值
+    total_dividend = Column(DOUBLE(asdecimal=False))  # 红利总额(元)
+    cash_dividend = Column(DOUBLE(asdecimal=False))  # 现金分红金额(元)
+    reinvest_amount = Column(DOUBLE(asdecimal=False))  # 再投资金额(元)
+    carry_amount = Column(DOUBLE(asdecimal=False))  # 业绩报酬金额(元)
+    share_changed = Column(DOUBLE(asdecimal=False), nullable=False)  # 份额变更
+    share_after_trans = Column(DOUBLE(asdecimal=False), nullable=False)  # 交易后份额
