@@ -100,12 +100,12 @@ class FundDailyCollection(Base):
     benchmark_name = Column(CHAR(64)) # 跟踪标的
 
     # basic.FundRate
-    zs = Column(DOUBLE(asdecimal=False))  # 招商评级
-    sh3 = Column(DOUBLE(asdecimal=False))  # 上海证券评级三年期
-    sh5 = Column(DOUBLE(asdecimal=False))  # 上海证券评级五年期
-    jajx = Column(DOUBLE(asdecimal=False))  # 济安金信评级
-    mornstar_3y = Column(DOUBLE(asdecimal=False))  # 晨星三年评级
-    mornstar_5y = Column(DOUBLE(asdecimal=False))  # 晨星五年评级
+    zs = Column(Integer)  # 招商评级
+    sh3 = Column(Integer)  # 上海证券评级三年期
+    sh5 = Column(Integer)  # 上海证券评级五年期
+    jajx = Column(Integer)  # 济安金信评级
+    mornstar_3y = Column(Integer)  # 晨星三年评级
+    mornstar_5y = Column(Integer)  # 晨星五年评级
 
     # basic.FundAlpha
     track_err = Column(DOUBLE(asdecimal=False))  # 跟踪误差
