@@ -184,13 +184,13 @@ class HybridPainter(object):
         plt.show()
 
     @staticmethod
-    def plot_taa_detail(df):
+    def plot_taa_detail(df, title):
         df.plot(figsize=(14,8))
         _res = []
         for index_id, v in df.iloc[-1].to_dict().items():
             _res.append(f'{index_id}:{round(v,3)}')
         s = ' '.join(_res)
-        plt.title('index pct', fontsize=25)
+        plt.title(title, fontsize=25)
         plt.legend(loc='lower left', fontsize=15)
         plt.suptitle(s,y=0.87,fontsize=17)
         plt.grid()
@@ -358,7 +358,6 @@ class HybridPainter(object):
 
     @staticmethod
     def fund_rank_recent_analysis(fund_id,index_id,score_dict,fund_info,fund_indicator,fund_nav,index_price,score_func,score_select):
-
         _res = []
         indicators = []
         for k,v in score_func.__dict__.items():
@@ -410,10 +409,8 @@ class HybridPainter(object):
         plt.title(f'{fund_id} {desc_name} indicator periods price_ratio', fontsize=25)
         plt.grid()
         plt.show()
-
         df['price_ratio'].plot(figsize=(16,8))
         plt.title(f'{fund_id} {desc_name} price_ratio', fontsize=25)
         plt.grid()
         plt.show()
-
         return result
\ No newline at end of file
