@@ -784,6 +784,7 @@ class ReportHelper:
             res_df = pd.concat(_res_dt_df, axis=0, sort=True)
         #res_df.loc[:,'rets'] = res_df['ret'] * res_df['weight']
         res_df = res_df.sort_values('rets',ascending=False)
+        res_df['_rets'] = res_df['rets']
         res_df.loc[:,'rets'] = [str(int(i*10000))+'BP' for i in res_df.loc[:,'rets']]
         desc_dic = fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']
         index_dic = fund_info[['fund_id','index_id']].set_index('fund_id').to_dict()['index_id']
@@ -823,8 +824,13 @@ class ReportHelper:
             df_2 = _res_df[1]
             df_2 = df_1.iloc[-1] * df_2
             res_index_df = df_1.iloc[:-1].append(df_2, sort=True)
-        AssetPainter.plot_index_price_ratio(res_index_df.dropna(),'price_ratio')
+       
         res_df = res_df.rename(columns={'ret':'fund_ret'})
+        res_tmp = res_df[['_rets','index_id']].groupby('index_id').sum()[['_rets']]
+        w = (res_tmp*10000).round(1).to_dict()['_rets']
+        st = [ f'{k} :{v}BP ' for k, v in w.items()]
+        st = ''.join(st)
+        AssetPainter.plot_index_price_ratio(res_index_df.dropna(),'price_ratio',st)
         res_df['fund_ret'] = res_df.fund_ret.map(lambda x: str(round(x*100,2)) +'%')
         res_df['weight'] = res_df.weight.map(lambda x: str(round(x*100,2)) +'%')
         res_df = res_df[['begin_date','end_date','desc_name','index_id','fund_ret','weight','rets']]
