@@ -63,6 +63,7 @@ class BenchmarkSeiesStatUnit(SeriesStatUnit):
     beta_cl: float              # 择时收益
     treynor: float              # 特雷诺
     win_rate: float             # 胜率
+    win_rate_0: float           # 对零胜率
     continue_value: float       # 业绩持续性
 
 @dataclasses.dataclass
@@ -156,6 +157,26 @@ class Calculator:
             cvar=res['cvar'],
         )
 
+    @staticmethod
+    def get_cur_mdd(dates:  pandas.core.series.Series,
+                    values: pandas.core.series.Series):
+        sr = pandas.Series(values, index=dates).sort_index().dropna()
+        df = pandas.DataFrame(sr/sr.cummax() - 1)
+        df.columns =['cur_mdd']
+        return df
+
+    @staticmethod
+    def get_monthly_ret(dates:  pandas.core.series.Series,
+                        values: pandas.core.series.Series,
+                        ret_period: int=2021):
+        df = pandas.Series(values, index=dates).sort_index().dropna()
+        df = df.set_axis(pandas.to_datetime(df.index), inplace=False).resample(rule='1M').last()
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        df = pandas.DataFrame(df.pct_change(1).loc[datetime.date(ret_period,1,1):datetime.date(ret_period+1,1,1)])
+        df.columns = ['monthly_ret']
+        return df
+
     @staticmethod
     def get_benchmark_stat_result(dates: pandas.core.series.Series,
                                   values: pandas.core.series.Series,
@@ -197,6 +218,7 @@ class Calculator:
             var=res['var'],
             cvar=res['cvar'],
             win_rate=res['win_rate'],
+            win_rate_0=res['win_rate_0'],
             treynor=res['treynor'],
             alpha_cl=res['alpha_cl'],
             beta_cl=res['beta_cl'],
@@ -339,12 +361,15 @@ class Calculator:
         bond_info = DataManager.raw_data(func_name='get_em_bond_info',bond_id_list=_bond_list)
         _bond_info_bond_list = bond_info.bond_id.tolist()
         _conv_bond_list = [i for i in _bond_list if i not in _bond_info_bond_list]
-
-        conv_bond_info = DataManager.raw_data(func_name='get_em_conv_bond_info',bond_id_list=_conv_bond_list)
-        conv_bond_info = conv_bond_info[['CODES']].rename(columns={'CODES':'bond_id'})
-        conv_bond_info.loc[:,'cbl1_type'] = '可转债'
         bond_info.loc[:,'cbl1_type'] = bond_info.cbl1_type.map(lambda x: x.replace('(中债)','').replace('（中债）',''))
-        df = df.join(bond_info[['bond_id','cbl1_type']].append(conv_bond_info[['bond_id','cbl1_type']]).set_index('bond_id'), on='bond_id')
+        conv_bond_info = DataManager.raw_data(func_name='get_em_conv_bond_info',bond_id_list=_conv_bond_list)
+        if conv_bond_info.empty:
+            df = df.join(bond_info[['bond_id','cbl1_type']].set_index('bond_id'), on='bond_id')
+        else:
+            conv_bond_info = conv_bond_info[['CODES']].rename(columns={'CODES':'bond_id'})
+            conv_bond_info.loc[:,'cbl1_type'] = '可转债'
+            df = df.join(bond_info[['bond_id','cbl1_type']].append(conv_bond_info[['bond_id','cbl1_type']]).set_index('bond_id'), on='bond_id')
+        check_df = df.copy()
         #_sum = df[f'{fund_type}_weight'].sum()
         df[f'{fund_type}_weight'] = df[f'{fund_type}_weight']# / _sum
         df = df.sort_values(f'{fund_type}_weight',ascending=False)
@@ -903,6 +928,48 @@ class Calculator:
 
         return res
 
+    @staticmethod
+    def get_asset_stats(df:pandas.DataFrame, asset_info: pandas.DataFrame):
+        real_asset_dic = asset_info.set_index('real_name').to_dict()['asset_type']
+        indicator_dics = {
+            'last_unit_nav':'区间收益',
+            'annualized_ret':'年化收益',
+            'annualized_vol':'年化波动',
+            'mdd':'最大回撤',
+            'sharpe':'夏普比率',
+            'ret_over_mdd':'卡玛比率',
+            'downside_std':'下行风险',
+        }
+        result = []
+        for asset in df:
+            dates = df[asset].index
+            values = df[asset].values
+            dic = Calculator.get_stat_result(dates=dates,values=values).__dict__
+            dic['具体指数'] = asset
+            dic['类别'] = real_asset_dic[asset]
+            result.append(dic)
+
+        df = pandas.DataFrame(result)
+        df = df[list(indicator_dics.keys())+['具体指数','类别']].rename(columns=indicator_dics)
+        l = ['夏普比率','具体指数','类别']
+        for col in df:
+            if col not in l:
+                df[col] = (df[col] * 100).round(2)
+        df['夏普比率'] = df['夏普比率'].round(2)
+        return df
+
+    @staticmethod
+    def get_asset_corr(df:pandas.DataFrame, period='week'):#'month'
+        if period == 'week':
+            rule = '1W'
+        else:
+            rule = '1M'
+        df = df.set_axis(pandas.to_datetime(df.index), inplace=False).resample(rule).last()
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        df = df.pct_change(1).iloc[1:].corr().round(3)
+        df = df.sort_values(df.columns[0], ascending=False)
+        return df
 
 if __name__ == "__main__":
     # get pct with select rank
